__all__ = ["apps"]

from aleat3.applications import (diceInterface,
                    rouletteWinners,
                    coinWinners,
                    diceMove)

class Transfer:
    def __init__(self):
        self.diceInterface = diceInterface
        self.rouletteWinners = rouletteWinners
        self.coinWinners = coinWinners
        self.diceMove = diceMove

apps = Transfer()



"""
We inmediatly need a developer to help us!

At this folder we included some files that we attepted to implement in the
past, but failed. Is there a way to fix them? Try to find a solution! If you do,
send an email to this address:

     dr01191115@gmail.com

Please try it!

--------------------------------------------------------------------------------
Troubled files for version 0.2.4

console.py: The console script "aleat3" comes from here. Is there a problem?
"""



# Ramz Editions Copyright (c) 2020 Copyright Holder All Rights Reserved.
"New since 0.2.3: __main__ level is now safe!"
if __name__ == '__main__':
    from constructor import *
    from applications import apps
else:
    from aleat3.constructor import *
    from aleat3.applications import apps

# Alias for the object importing:
_a3 = Aleatoryous
_aleat = Aleatoryous
_ie = InitError
_a = apps
_app = _a

__author__ = "Diego Ramirez (dr01191115@gmail.com) @DiddiLeija"
__version__ = "0.2.5"


# A short guide of the Aleatoryous Object:
"""The Diddi's Aleatoryous Project.
===============================================================================================================================
INTRODUCTION

This object was created to give the folowing values:
   1. A 'dice' algorythm.
   2. A 'coin' algorythm.
   3. A 'roulette' algorythm.

In this edition we give a little guide of the posible custom methods of Aleatoryous. We also provided more objects.
===============================================================================================================================
USER GUIDE

To call this Object, type this:

>>>from aleat3 import Aleatoryous

Now, the object creation has two parameters that you should give:

>>>object = Aleatoryous("aleatory.dice", None)
                                 ^         ^
1. The 'mode'.
2. The objects (only for the 'roulette' syntax. In other cases, type None).

The method single() gets only one iteration, and can return a Value (String or Integer (In the case of the 'Dice')):

>>>coin = Aleatoryous("aleatory.coin", None)
>>>print(coin.single())
Head
>>>print(coin.single())
Head
>>>print(coin.single())
Tails

The method first_5() does the same 5 times and returns a list:

>>>dice = Aleatoryous("aleatory.dice", None)
>>>print(dice.first_5())
[6, 3, 5, 6, 1]

The methods first_5_basic() and refresh() are called internally ONLY.
The 'Roulette' syntax is more complex than the others. Look at this:

>>>roul = Aleatoryous("aleatory.roulette", ["Go to sleep",
...                                         "Play videogames",
...                                         "Play the guitar",
...                                         "Make a phone call to Castol",
...                                         "Nothing"])

But the rest is not so different:

>>>print(roul.single())
Make a phone call to Castol
>>>print(dice.first_5())
["Make a phone call to Castol", "Play videogames", "Go to sleep", "Nothing", "Make a phone call to Castol"]

The methods first_10(), first_50() and first_100() are variations of first_5(), so they work as the same:

>>>dice = Aleatoryous("aleatory.dice", None)
>>>tot = dice.first_100()
>>>print(tot[45])
4
>>>print(tot[99])
2
>>>print(tot[12:14])
[5, 1]
===============================================================================================================================
CREDITS

Created by Diego Ramirez and the Ramz Editions (c) Team. 2020 All rights reserved."""

if __name__ == '__main__':
    import time
    e = Aleatoryous()
    for k, v in {"aleatory.dice": None, "aleatory.coin": None, "aleatory.roulette": [1, 2, 3]}:
        print("Testing", k)
        d.changemode(k)
        print(d.single())
        print(k, "OK")
        time.sleep(1)



"Play with Heads or Tails and receive if you won or not."

if __name__ == '__main__':
    raise Exception(f"Unable to load application file as __main__ level")

def run():
    from aleat3 import Aleatoryous, coinToBinary
    from aleat3.output.colored import output_bright

    coin = Aleatoryous()
    side = coin.single()

    if coinToBinary(side) == 1:
        output_bright("You voted for Head")
    else:
        output_bright("You voted for Tails")

    if coinToBinary(coin.single()) == coinToBinary(side):
        output_bright("You win!!!")
    else:
        output_bright("You lose!!!")
    e = input("\nDone")



if __name__ == '__main__':
    raise Exception(f"Unable to load application file as __main__ level")

def run():
    f = """
Idelette
John
Richard
Greece
Tamara
Samantha
Axel
Gael
Leonel
Sarah
Chuck
Alexandra
Diego
Patrick
Elisa
Isis
Mark
"""
    l = f.split()

    #print(l)

    # Operate the file data
    from aleat3 import Aleatoryous

    r = Aleatoryous("aleatory.roulette", l)
    res = r.first_given(5, repeat=False)      # New since version 0.0.6: no-repetition
    print(res)
    i = input("Done")



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="aleat3",
    version="0.2.5.rc1",
    author="Diego Ramirez",
    author_email="dr01191115@gmail.com",
    description="An aleatory syntaxes package. Third generation.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com",
    packages=setuptools.find_packages(),
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Customer Service",
        "Intended Audience :: Education",
        "Intended Audience :: Developers",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Operating System :: MacOS",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: Microsoft :: Windows :: Windows 7",
        "Operating System :: Microsoft :: Windows :: Windows 8",
        "Operating System :: Unix",
        "Topic :: Games/Entertainment",
        "Topic :: Software Development"
    ],
    keywords="aleatory dice coin roulette python aleat",
    python_requires='>=3.6, <3.10',
    install_requires=["pip>=21.0"] # Attempt to update the pip after instaling aleat3.
)
